@@ -8,6 +8,7 @@ mod process;
 mod option;
 mod define;
 mod db;
+mod model;
 mod parser;
 mod handler;
 mod interface;
@@ -61,7 +62,7 @@ async fn main() {
         }
         let opt = parser::parse_port_args(matches);
         handler::handle_port_scan(opt).await;
-    }else if matches.is_present("host") {
+    }else if matches.is_present("network") || matches.is_present("host") {
         if require_admin && !process::privileged() {
             println!("{} This feature requires administrator privileges. ","Error:".red());
             std::process::exit(0);
@@ -81,19 +82,27 @@ fn get_app_settings<'a, 'b>() -> App<'a, 'b> {
         .author(define::CRATE_AUTHOR_GITHUB)
         .about(crate_description!())
         .arg(Arg::with_name("port")
-            .help("Scan ports of the specified host. \nUse default port list if port range omitted. \nExamples \n-p 192.168.1.8 -d \n-p 192.168.1.8:1-1000 \n-p 192.168.1.8:22,80,8080 \n-p 192.168.1.8 -l custom-list.txt")
+            .help("Scan ports of the specified host. \nUse default port list if port range omitted. \nExamples \n-p 192.168.1.8 -s -O \n-p 192.168.1.8:1-1000 \n-p 192.168.1.8:22,80,8080 \n-p 192.168.1.8 -l custom-list.txt")
             .short("p")
             .long("port")
             .takes_value(true)
             .value_name("ip_addr:port")
             .validator(validator::validate_port_opt)
         )
-        .arg(Arg::with_name("host")
-            .help("Scan hosts in specified network or list \nExamples \n-n 192.168.1.0 -d \n-n -l custom-list.txt")
+        .arg(Arg::with_name("network")
+            .help("Scan hosts in specified network \nExample: -n 192.168.1.0 -O")
             .short("n")
-            .long("host")
+            .long("network")
             .takes_value(true)
             .value_name("ip_addr")
+            .validator(validator::validate_network_opt)
+        )
+        .arg(Arg::with_name("host")
+            .help("Scan hosts in specified host-list \nExamples \n-H custom-list.txt -O \n-H 192.168.1.10,192.168.1.20,192.168.1.30 -O")
+            .short("H")
+            .long("host")
+            .takes_value(true)
+            .value_name("host_list")
             .validator(validator::validate_host_opt)
         )
         .arg(Arg::with_name("timeout")
@@ -112,6 +121,14 @@ fn get_app_settings<'a, 'b>() -> App<'a, 'b> {
             .value_name("duration")
             .validator(validator::validate_waittime)
         )
+        .arg(Arg::with_name("rate")
+            .help("Set sendrate in ms - Ex: -r 1")
+            .short("r")
+            .long("rate")
+            .takes_value(true)
+            .value_name("duration")
+            .validator(validator::validate_waittime)
+        )
         .arg(Arg::with_name("portscantype")
             .help("Set port scan type (default:SYN) - SYN, CONNECT")
             .short("P")
@@ -136,10 +153,10 @@ fn get_app_settings<'a, 'b>() -> App<'a, 'b> {
             .value_name("file_path")
             .validator(validator::validate_filepath)
         )
-        .arg(Arg::with_name("detail")
-            .help("Get details (service version)")
-            .short("d")
-            .long("detail")
+        .arg(Arg::with_name("service")
+            .help("Enable service detection")
+            .short("s")
+            .long("service")
             .takes_value(false)
         )
         .arg(Arg::with_name("acceptinvalidcerts")
@@ -148,10 +165,10 @@ fn get_app_settings<'a, 'b>() -> App<'a, 'b> {
             .long("acceptinvalidcerts")
             .takes_value(false)
         )
-        .arg(Arg::with_name("save")
-            .help("Save scan result to file - Ex: -s result.json")
-            .short("s")
-            .long("save")
+        .arg(Arg::with_name("output")
+            .help("Save scan result in json format - Ex: -o result.json")
+            .short("o")
+            .long("output")
             .takes_value(true)
             .value_name("file_path")
         )
@@ -161,8 +178,14 @@ fn get_app_settings<'a, 'b>() -> App<'a, 'b> {
             .long("async")
             .takes_value(false)
         )
+        .arg(Arg::with_name("OS")
+            .help("Enable OS detection")
+            .short("O")
+            .long("OS")
+            .takes_value(false)
+        )
         .group(ArgGroup::with_name("mode")
-            .args(&["port", "host"])
+            .args(&["port", "network", "host"])
         )
         .setting(AppSettings::DeriveDisplayOrder)
         ;
